.. py:currentmodule:: rubin_sim

.. _satellite-constellations:

########################
Satellite Constellations
########################

The ``rubin_sim.satellite_constellations`` module contains
tools for creating and propagating satellite mega constellations
to evaluate their impact (in terms of streaks) in Rubin images.
There is also an extension for ``rubin_scheduler`` that will add
"satellite dodging" to the scheduler logic, at a cost of overall image depth.
